colour_hdri.sampling.grossberg2003 Module — Colour - HDRI 0.1.0 documentation

# colour_hdri.sampling.grossberg2003 Module

## Grossberg (2003) Histogram Based Image Sampling

Defines Grossberg (2003) histogram based image sampling objects:

- `samples_Grossberg2003()`

References

[1] | Grossberg, M. D., & Nayar, S. K. (2003). Determining the camera response from images: What is knowable? IEEE Transactions on Pattern Analysis and Machine Intelligence, 25(11), 1455–1467. doi:10.1109/TPAMI.2003.1240119

[2] | Banterle, F., & Benedetti, L. (2014). PICCANTE: An Open and Portable Library for HDR Imaging.

`colour_hdri.sampling.grossberg2003.` `samples_Grossberg2003`(image_stack, samples=1000, n=256)

  Returns the samples for given image stack intensity histograms using Grossberg (2003) method.

  Parameters: | image_stack (array_like) – Stack of single channel or multi-channel floating point images. samples (int, optional) – Samples count. n (int, optional) – Histograms bins count.
  Returns: | Intensity histograms samples.
  Return type: | ndarray